@@ -1,9 +1,5 @@
 # bash completion support for git-extras.
 
-_git_bug(){
-  __git_extras_workflow "bug"
-}
-
 _git_changelog(){
   local s_opts=( '-a' '-l' '-t' '-f' '-s' '-n' '-p' '-x' '-h' '?' )
   local l_opts=(
@@ -25,10 +21,6 @@ _git_changelog(){
   __gitcomp "$merged_opts_str"
 }
 
-_git_chore(){
-  __git_extras_workflow "chore"
-}
-
 _git_authors(){
   __gitcomp "-l --list --no-email"
 }
@@ -49,6 +41,10 @@ _git_count(){
   __gitcomp "--all"
 }
 
+__git_cp(){
+  __git_complete_file
+}
+
 _git_delete_branch(){
   __gitcomp "$(__git_heads)"
 }
@@ -127,10 +123,6 @@ _git_reauthor(){
    __gitcomp "${comp}"
 }
 
-_git_refactor(){
-  __git_extras_workflow "refactor"
-}
-
 _git_scp(){
   __git_complete_remote_or_refspec
 }
@@ -150,3 +142,7 @@ _git_squash(){
 _git_undo(){
    __gitcomp "--hard --soft -h -s"
 }
+
+_git_browse(){
+  __git_complete_remote_or_refspec
+}
